@@ -5,22 +5,19 @@ A VM is not actually different from a Linker, we just decided
 VM was a better name at some point.
 
 """
-
-
-from . import link
-from collections import defaultdict
 import logging
 import sys
 import time
 import warnings
 import platform
 
-from theano.configparser import config, _config_var_list
-
 import theano.gof.cmodule
 
-from six import iteritems, itervalues
-from six.moves import xrange
+from collections import defaultdict
+
+from theano.configparser import config, _config_var_list
+
+from . import link
 
 logger = logging.getLogger(__name__)
 
@@ -231,7 +228,7 @@ class VM(object):
             profile.dependencies = self.dependencies
 
         # clear the timer info out of the buffers
-        for i in xrange(len(self.call_times)):
+        for i in range(len(self.call_times)):
             self.call_times[i] = 0.0
             self.call_counts[i] = 0
 
@@ -459,7 +456,7 @@ class Stack(VM):
         last_apply_stack_len = -1
 
         # This record all function inputs/shared variables and constants
-        for var, data in iteritems(self.storage_map):
+        for var, data in self.storage_map.items():
             if data[0] is None:
                 continue
             if hasattr(var.type, "get_shape_info"):
@@ -962,17 +959,17 @@ class VM_Linker(link.LocalLinker):
 
             nodes_idx_inv = {}
             vars_idx_inv = {}
-            for (node, i) in iteritems(nodes_idx):
+            for (node, i) in nodes_idx.items():
                 nodes_idx_inv[i] = node
-            for (var, i) in iteritems(vars_idx):
+            for (var, i) in vars_idx.items():
                 vars_idx_inv[i] = var
 
             # put storage_map and compute_map into a int-based scheme
             storage_map_list = [
-                storage_map[vars_idx_inv[i]] for i in xrange(len(vars_idx_inv))
+                storage_map[vars_idx_inv[i]] for i in range(len(vars_idx_inv))
             ]
             compute_map_list = [
-                compute_map[vars_idx_inv[i]] for i in xrange(len(vars_idx_inv))
+                compute_map[vars_idx_inv[i]] for i in range(len(vars_idx_inv))
             ]
             if nodes:
                 assert type(storage_map_list[0]) is list
@@ -982,7 +979,7 @@ class VM_Linker(link.LocalLinker):
             dependency_map = self.compute_gc_dependencies(storage_map)
             dependency_map_list = [
                 [vars_idx[d] for d in dependency_map[vars_idx_inv[i]]]
-                for i in xrange(len(vars_idx_inv))
+                for i in range(len(vars_idx_inv))
             ]
 
             # build the pointers to node inputs and offsets
@@ -1003,7 +1000,7 @@ class VM_Linker(link.LocalLinker):
 
             # build the var owner array
             var_owner = [None] * len(vars_idx)
-            for (var, i) in iteritems(vars_idx):
+            for (var, i) in vars_idx.items():
                 if var.owner:
                     var_owner[i] = nodes_idx[var.owner]
 
@@ -1030,7 +1027,7 @@ class VM_Linker(link.LocalLinker):
             # values of the update expressions).
             update_storage = []
             update_in_from_out = {}
-            for (ivar, ovar) in iteritems(updated_vars):
+            for (ivar, ovar) in updated_vars.items():
                 update_in_from_out[vars_idx[ovar]] = vars_idx[ivar]
             for oidx in output_vars:
                 if oidx in update_in_from_out:
@@ -1075,9 +1072,18 @@ class VM_Linker(link.LocalLinker):
             if not lazy:
                 # there is no conditional in the graph
                 if self.allow_gc:
-                    vm = LoopGC(nodes, thunks, pre_call_clear, post_thunk_clear,)
+                    vm = LoopGC(
+                        nodes,
+                        thunks,
+                        pre_call_clear,
+                        post_thunk_clear,
+                    )
                 else:
-                    vm = Loop(nodes, thunks, pre_call_clear,)
+                    vm = Loop(
+                        nodes,
+                        thunks,
+                        pre_call_clear,
+                    )
             else:
                 # Needed when allow_gc=True and profiling
                 deps = self.compute_gc_dependencies(storage_map)
@@ -1095,7 +1101,11 @@ class VM_Linker(link.LocalLinker):
         return vm
 
     def make_all(
-        self, profiler=None, input_storage=None, output_storage=None, storage_map=None,
+        self,
+        profiler=None,
+        input_storage=None,
+        output_storage=None,
+        storage_map=None,
     ):
         fgraph = self.fgraph
         order = self.schedule(fgraph)
@@ -1171,7 +1181,7 @@ class VM_Linker(link.LocalLinker):
             or self.callback
             or self.callback_input
         ):
-            for pair in itervalues(reallocated_info):
+            for pair in reallocated_info.values():
                 storage_map[pair[1]] = storage_map[pair[0]]
 
         computed, last_user = link.gc_helper(order)
