@@ -11,19 +11,18 @@ it picks each entry of a matrix according to the condition) while `ifelse`
 is a global operation with a scalar condition.
 """
 
-from copy import deepcopy
-from theano.compat import izip
 import logging
 
 import numpy as np
 
 import theano.tensor
+
+from copy import deepcopy
+
 from theano.tensor import TensorType
 from theano import gof
 from theano.gof import Op, Apply
 
-from six import iteritems
-from six.moves import xrange
 from theano.compile import optdb
 from theano.tensor import opt
 from theano.scan_module.scan_utils import clone
@@ -70,7 +69,7 @@ class IfElse(Op):
             # check destroyhandler and others to ensure that a view_map with
             # multiple inputs can work
             view_map = {}
-            for idx in xrange(n_outs):
+            for idx in range(n_outs):
                 view_map[idx] = [idx + 1]
             self.view_map = view_map
         self.as_view = as_view
@@ -162,9 +161,11 @@ class IfElse(Op):
         return out_shapes
 
     def make_node(self, c, *args):
-        assert len(args) == 2 * self.n_outs, (
-            "Wrong number of arguments to make_node: "
-            "expected %d, got %d" % (2 * self.n_outs, len(args))
+        assert (
+            len(args) == 2 * self.n_outs
+        ), "Wrong number of arguments to make_node: " "expected %d, got %d" % (
+            2 * self.n_outs,
+            len(args),
         )
         c = theano.tensor.as_tensor_variable(c)
         if not self.gpu:
@@ -182,7 +183,7 @@ class IfElse(Op):
         ts = args[: self.n_outs]
         fs = args[self.n_outs :]
 
-        for t, f in izip(ts, fs):
+        for t, f in zip(ts, fs):
             if t.type != f.type:
                 raise TypeError(
                     ("IfElse requires same types for true and " "false return values"),
@@ -267,13 +268,13 @@ class IfElse(Op):
                 if truthval != 0:
                     ls = [
                         idx + 1
-                        for idx in xrange(self.n_outs)
+                        for idx in range(self.n_outs)
                         if not compute_map[ts[idx]][0]
                     ]
                     if len(ls) > 0:
                         return ls
                     else:
-                        for out, t in izip(outputs, ts):
+                        for out, t in zip(outputs, ts):
                             compute_map[out][0] = 1
                             val = storage_map[t][0]
                             if self.as_view:
@@ -287,13 +288,13 @@ class IfElse(Op):
                 else:
                     ls = [
                         1 + idx + self.n_outs
-                        for idx in xrange(self.n_outs)
+                        for idx in range(self.n_outs)
                         if not compute_map[fs[idx]][0]
                     ]
                     if len(ls) > 0:
                         return ls
                     else:
-                        for out, f in izip(outputs, fs):
+                        for out, f in zip(outputs, fs):
                             compute_map[out][0] = 1
                             # can't view both outputs unless destroyhandler
                             # improves
@@ -364,7 +365,7 @@ def ifelse(condition, then_branch, else_branch, name=None):
     # we will store them in these new_... lists.
     new_then_branch = []
     new_else_branch = []
-    for then_branch_elem, else_branch_elem in izip(then_branch, else_branch):
+    for then_branch_elem, else_branch_elem in zip(then_branch, else_branch):
         if not isinstance(then_branch_elem, theano.Variable):
             then_branch_elem = theano.tensor.as_tensor_variable(then_branch_elem)
         if not isinstance(else_branch_elem, theano.Variable):
@@ -572,7 +573,7 @@ def cond_merge_ifs_true(node):
         return False
 
     old_ins = list(node.inputs)
-    for pos, var in iteritems(replace):
+    for pos, var in replace.items():
         old_ins[pos] = var
     return op(*old_ins, **dict(return_list=True))
 
@@ -599,7 +600,7 @@ def cond_merge_ifs_false(node):
         return False
 
     old_ins = list(node.inputs)
-    for pos, var in iteritems(replace):
+    for pos, var in replace.items():
         old_ins[pos] = var
     return op(*old_ins, **dict(return_list=True))
 
@@ -667,9 +668,9 @@ def cond_remove_identical(node):
 
     # sync outs
     out_map = {}
-    for idx in xrange(len(node.outputs)):
+    for idx in range(len(node.outputs)):
         if idx not in out_map:
-            for jdx in xrange(idx + 1, len(node.outputs)):
+            for jdx in range(idx + 1, len(node.outputs)):
                 if ts[idx] == ts[jdx] and fs[idx] == fs[jdx] and jdx not in out_map:
                     out_map[jdx] = idx
 
@@ -680,7 +681,7 @@ def cond_remove_identical(node):
     nw_fs = []
     inv_map = {}
     pos = 0
-    for idx in xrange(len(node.outputs)):
+    for idx in range(len(node.outputs)):
         if idx not in out_map:
             inv_map[idx] = pos
             pos = pos + 1
@@ -693,7 +694,7 @@ def cond_remove_identical(node):
     new_outs = new_ifelse(*new_ins, **dict(return_list=True))
 
     rval = []
-    for idx in xrange(len(node.outputs)):
+    for idx in range(len(node.outputs)):
         if idx in out_map:
             rval += [new_outs[inv_map[out_map[idx]]]]
         else:
