@@ -1,16 +1,18 @@
 import numpy as np
-from six.moves import xrange
 
 import theano
-from theano.tensor import basic
-from theano.tensor import nlinalg  # noqa
-from theano import gof, scalar
-from theano.gof import Generic, ParamsType, EnumList
-from theano import gradient
-from theano.gradient import DisconnectedType, disconnected_type
-from theano.scalar import int32 as int_t
 
-tensor = basic
+from collections.abc import Collection
+
+from theano.gof import Op, Apply, Generic, ParamsType, EnumList
+from theano.tensor import basic, nlinalg
+from theano.scalar import int32 as int_t, upcast
+from theano.gradient import (
+    DisconnectedType,
+    disconnected_type,
+    _float_zeros_like,
+    grad_undefined,
+)
 
 
 class CpuContiguous(theano.Op):
@@ -195,8 +197,8 @@ class SearchsortedOp(theano.Op):
         else:
             x, v = inputs
 
-        x_grad = gradient._float_zeros_like(x)
-        v_grad = gradient._float_zeros_like(v)
+        x_grad = _float_zeros_like(x)
+        v_grad = _float_zeros_like(v)
         if num_ins == 3:
             return [x_grad, v_grad, disconnected_type()]
         else:
@@ -292,7 +294,10 @@ class CumOp(theano.Op):
     def perform(self, node, inputs, output_storage, params):
         x = inputs[0]
         z = output_storage[0]
-        z[0] = {"add": np.cumsum, "mul": np.cumprod}[self.mode](x, axis=self.axis)
+        if self.mode == "add":
+            z[0] = np.cumsum(x, axis=self.axis)
+        else:
+            z[0] = np.cumprod(x, axis=self.axis)
 
     def grad(self, inputs, output_gradients):
         (x,) = inputs
@@ -327,7 +332,7 @@ class CumOp(theano.Op):
 
     def infer_shape(self, node, shapes):
         if self.axis is None:
-            return [(tensor.prod(shapes[0]),)]  # Flatten
+            return [(basic.prod(shapes[0]),)]  # Flatten
 
         return shapes
 
@@ -575,7 +580,7 @@ def bincount(x, weights=None, minlength=None, assert_nonneg=False):
     return out
 
 
-def squeeze(x):
+def squeeze(x, axis=None):
     """
     Remove broadcastable dimensions from the shape of an array.
 
@@ -590,13 +595,26 @@ def squeeze(x):
     x
         Input data, tensor variable.
 
+    axis : None or int or tuple of ints, optional
+
+        Selects a subset of the single-dimensional entries in the
+        shape. If an axis is selected with shape entry greater than
+        one, an error is raised.
+
     Returns
     -------
     object
         `x` without its broadcastable dimensions.
 
     """
-    view = x.dimshuffle([i for i in range(x.ndim) if not x.broadcastable[i]])
+    if axis is None:
+        axis = range(x.ndim)
+    elif not isinstance(axis, Collection):
+        axis = (axis,)
+
+    view = x.dimshuffle(
+        [i for i in range(x.ndim) if not x.broadcastable[i] or i not in axis]
+    )
     return view
 
 
@@ -640,7 +658,7 @@ class RepeatOp(theano.Op):
         x = basic.as_tensor_variable(x)
         repeats = basic.as_tensor_variable(repeats)
 
-        if repeats.dtype not in tensor.integer_dtypes:
+        if repeats.dtype not in basic.integer_dtypes:
             raise TypeError("repeats.dtype must be an integer.")
 
         # Some dtypes are not supported by numpy's implementation of repeat.
@@ -766,7 +784,7 @@ def repeat(x, repeats, axis=None):
     .. versionadded:: 0.6
 
     """
-    repeats = tensor.as_tensor_variable(repeats)
+    repeats = basic.as_tensor_variable(repeats)
 
     if repeats.ndim > 1:
         raise ValueError("The dimension of repeats should not exceed 1.")
@@ -789,7 +807,7 @@ def repeat(x, repeats, axis=None):
             if axis < 0:
                 axis = x.ndim + axis
 
-        shape = [x.shape[i] for i in xrange(x.ndim)]
+        shape = [x.shape[i] for i in range(x.ndim)]
 
         # shape_ is the shape of the intermediate tensor which has
         # an additional dimension comparing to x. We use alloc to
@@ -809,22 +827,22 @@ def repeat(x, repeats, axis=None):
         # After the original tensor is duplicated along the additional
         # dimension, we reshape it to the expected output shape, and
         # return the output z.
-        z = tensor.alloc(x.dimshuffle(*dims_), *shape_).reshape(shape)
+        z = basic.alloc(x.dimshuffle(*dims_), *shape_).reshape(shape)
         return z
 
 
-class Bartlett(gof.Op):
+class Bartlett(Op):
     # See function bartlett for docstring
     __props__ = ()
 
     def make_node(self, M):
-        M = tensor.as_tensor_variable(M)
+        M = basic.as_tensor_variable(M)
         if M.ndim != 0:
             raise TypeError("%s only works on scalar input" % self.__class__.__name__)
         elif M.dtype not in theano.tensor.integer_dtypes:
             # dtype is a theano attribute here
             raise TypeError("%s only works on integer input" % self.__class__.__name__)
-        return gof.Apply(self, [M], [tensor.dvector()])
+        return Apply(self, [M], [basic.dvector()])
 
     def perform(self, node, inputs, out_):
         M = inputs[0]
@@ -833,7 +851,7 @@ class Bartlett(gof.Op):
 
     def infer_shape(self, node, in_shapes):
         temp = node.inputs[0]
-        M = tensor.switch(tensor.lt(temp, 0), tensor.cast(0, temp.dtype), temp)
+        M = basic.switch(basic.lt(temp, 0), basic.cast(0, temp.dtype), temp)
         return [[M]]
 
     def grad(self, inputs, output_grads):
@@ -871,7 +889,7 @@ def bartlett(M):
     return bartlett_(M)
 
 
-class FillDiagonal(gof.Op):
+class FillDiagonal(Op):
     # See function fill_diagonal for docstring
     __props__ = ()
 
@@ -879,8 +897,8 @@ class FillDiagonal(gof.Op):
         return [in_shapes[0]]
 
     def make_node(self, a, val):
-        a = tensor.as_tensor_variable(a)
-        val = tensor.as_tensor_variable(val)
+        a = basic.as_tensor_variable(a)
+        val = basic.as_tensor_variable(val)
         if a.ndim < 2:
             raise TypeError(
                 "%s: first parameter must have at least"
@@ -890,13 +908,13 @@ class FillDiagonal(gof.Op):
             raise TypeError(
                 "%s: second parameter must be a scalar" % self.__class__.__name__
             )
-        val = tensor.cast(val, dtype=scalar.upcast(a.dtype, val.dtype))
+        val = basic.cast(val, dtype=upcast(a.dtype, val.dtype))
         if val.dtype != a.dtype:
             raise TypeError(
                 "%s: type of second parameter must be the same as"
                 " the first's" % self.__class__.__name__
             )
-        return gof.Apply(self, [a, val], [a.type()])
+        return Apply(self, [a, val], [a.type()])
 
     def perform(self, node, inputs, output_storage):
         a = inputs[0].copy()
@@ -932,7 +950,7 @@ class FillDiagonal(gof.Op):
             )
         wr_a = fill_diagonal(grad, 0)  # valid for any number of dimensions
         # diag is only valid for matrices
-        wr_val = theano.tensor.nlinalg.diag(grad).sum()
+        wr_val = nlinalg.diag(grad).sum()
         return [wr_a, wr_val]
 
 
@@ -973,7 +991,7 @@ def fill_diagonal(a, val):
     return fill_diagonal_(a, val)
 
 
-class FillDiagonalOffset(gof.Op):
+class FillDiagonalOffset(Op):
     # See function fill_diagonal_offset for docstring
     __props__ = ()
 
@@ -981,9 +999,9 @@ class FillDiagonalOffset(gof.Op):
         return [in_shapes[0]]
 
     def make_node(self, a, val, offset):
-        a = tensor.as_tensor_variable(a)
-        val = tensor.as_tensor_variable(val)
-        offset = tensor.as_tensor_variable(offset)
+        a = basic.as_tensor_variable(a)
+        val = basic.as_tensor_variable(val)
+        offset = basic.as_tensor_variable(offset)
         if a.ndim != 2:
             raise TypeError(
                 "%s: first parameter must have exactly"
@@ -997,7 +1015,7 @@ class FillDiagonalOffset(gof.Op):
             raise TypeError(
                 "%s: third parameter must be a scalar" % self.__class__.__name__
             )
-        val = tensor.cast(val, dtype=scalar.upcast(a.dtype, val.dtype))
+        val = basic.cast(val, dtype=upcast(a.dtype, val.dtype))
         if val.dtype != a.dtype:
             raise TypeError(
                 "%s: type of second parameter must be the same"
@@ -1010,7 +1028,7 @@ class FillDiagonalOffset(gof.Op):
                 % self.__class__.__name__
             )
 
-        return gof.Apply(self, [a, val, offset], [a.type()])
+        return Apply(self, [a, val, offset], [a.type()])
 
     def perform(self, node, inputs, output_storage):
         a = inputs[0].copy()
@@ -1079,7 +1097,7 @@ class FillDiagonalOffset(gof.Op):
 
         wr_val = grad.flatten()[start:end:step].sum()
 
-        wr_offset = theano.gradient.grad_undefined(
+        wr_offset = grad_undefined(
             self,
             2,
             offset,
@@ -1250,7 +1268,7 @@ class Unique(theano.Op):
             ret[0] = tuple(
                 [
                     node.fgraph.shape_feature.shape_ir(i, node.outputs[0])
-                    for i in xrange(ndim)
+                    for i in range(ndim)
                 ]
             )
         if self.return_inverse:
@@ -1273,14 +1291,11 @@ class Unique(theano.Op):
             self.axis = None
 
 
-class UnravelIndex(gof.Op):
-    __props__ = ("ndim", "order")
+class UnravelIndex(Op):
+    __props__ = ("order",)
 
-    def __init__(self, ndim, order="C"):
+    def __init__(self, order="C"):
         assert order in ("C", "F")
-        if not isinstance(ndim, int) or ndim < 1:
-            raise ValueError("ndim must be an integer greater than 0")
-        self.ndim = int(ndim)
         self.order = order
 
     def make_node(self, indices, dims):
@@ -1298,12 +1313,12 @@ class UnravelIndex(gof.Op):
         if dims.ndim != 1:
             raise TypeError("dims must be a 1D array")
 
-        return gof.Apply(
+        return Apply(
             self,
             [indices, dims],
             [
                 basic.TensorType(dtype="int64", broadcastable=(False,) * indices.ndim)()
-                for i in xrange(self.ndim)
+                for i in range(basic.get_vector_length(dims))
             ],
         )
 
@@ -1312,9 +1327,9 @@ class UnravelIndex(gof.Op):
 
     def perform(self, node, inp, out):
         indices, dims = inp
-        res = np.unravel_index(indices, dims)
+        res = np.unravel_index(indices, dims, order=self.order)
         assert len(res) == len(out)
-        for i in xrange(len(out)):
+        for i in range(len(out)):
             ret = theano._asarray(res[i], node.outputs[0].dtype)
             if ret.base is not None:
                 # NumPy will return a view when it can.
@@ -1323,15 +1338,11 @@ class UnravelIndex(gof.Op):
             out[i][0] = ret
 
 
-def unravel_index(indices, dims, order="C", ndim=None):
+def unravel_index(indices, dims, order="C"):
     """
     Converts a flat index or array of flat indices into a tuple
     of coordinate arrays.
 
-    This method is similar to the NumPy version, except for the
-    additional ``ndim`` parameter. This parameter is required if
-    the length of ``dims`` cannot be determined automatically.
-
     Parameters
     ----------
     indices : Theano or NumPy array
@@ -1342,10 +1353,6 @@ def unravel_index(indices, dims, order="C", ndim=None):
     order : {'C', 'F'}, optional
         Determines whether the indices should be viewed as indexing in
         row-major (C-style) or column-major (Fortran-style) order.
-    ndim : int, optional
-        Specifies the number of dimensions, i.e., the length of
-        ``dims``. This is required if the dimensions cannot be determined
-        automatically from ``dims`` itself.
 
     Returns
     -------
@@ -1358,26 +1365,14 @@ def unravel_index(indices, dims, order="C", ndim=None):
     ravel_multi_index
 
     """
-    if ndim is None:
-        try:
-            ndim = basic.get_vector_length(dims)
-        except ValueError:
-            raise ValueError(
-                "The length of the provided dimension list (%s) cannot "
-                "be automatically determined, so Theano is not able "
-                "to know what the number of dimensions of the unraveled "
-                "index will be. You can provide the 'ndim' keyword "
-                "argument to 'unravel_index' to avoid this problem." % str(dims)
-            )
-
-    res = UnravelIndex(ndim=ndim, order=order)(indices, dims)
-    if ndim == 1:
+    res = UnravelIndex(order=order)(indices, dims)
+    if not isinstance(res, (list, tuple)):
         return (res,)
     else:
         return tuple(res)
 
 
-class RavelMultiIndex(gof.Op):
+class RavelMultiIndex(Op):
     __props__ = ("mode", "order")
 
     def __init__(self, mode="raise", order="C"):
@@ -1402,7 +1397,7 @@ class RavelMultiIndex(gof.Op):
         if dims.ndim != 1:
             raise TypeError("dims must be a 1D array")
 
-        return gof.Apply(
+        return Apply(
             self,
             multi_index + [dims],
             [
@@ -1460,3 +1455,80 @@ def ravel_multi_index(multi_index, dims, mode="raise", order="C"):
         raise TypeError("multi_index must be a tuple or a list.")
     args = tuple(multi_index) + (dims,)
     return RavelMultiIndex(mode=mode, order=order)(*args)
+
+
+def broadcast_shape(*arrays, **kwargs):
+    """Compute the shape resulting from broadcasting arrays.
+
+    Parameters
+    ----------
+    *arrays: Tuple[TensorVariable] or Tuple[Tuple[Variable]]
+        A tuple of tensors, or a tuple of shapes (as tuples),
+        for which the broadcast shape is computed.
+    arrays_are_shapes: bool (Optional)
+        Indicates whether or not the `arrays` contains shape tuples.
+        If you use this approach, make sure that the broadcastable dimensions
+        are (scalar) constants with the value `1` or `1` exactly.
+
+    """
+    one = theano.scalar.ScalarConstant(theano.scalar.int64, 1)
+
+    arrays_are_shapes = kwargs.pop("arrays_are_shapes", False)
+    if arrays_are_shapes:
+        max_dims = max(len(a) for a in arrays)
+
+        array_shapes = [
+            (one,) * (max_dims - len(a))
+            + tuple(one if getattr(sh, "value", sh) == 1 else sh for sh in a)
+            for a in arrays
+        ]
+    else:
+        max_dims = max(a.ndim for a in arrays)
+
+        array_shapes = [
+            (one,) * (max_dims - a.ndim)
+            + tuple(one if bcast else sh for sh, bcast in zip(a.shape, a.broadcastable))
+            for a in arrays
+        ]
+
+    result_dims = []
+
+    for dim_shapes in zip(*array_shapes):
+        non_bcast_shapes = [shape for shape in dim_shapes if shape != one]
+
+        if len(non_bcast_shapes) > 0:
+            # Either there's only one non-broadcastable dimensions--and that's
+            # what determines the dimension size, or there are multiple
+            # non-broadcastable dimensions that must be equal
+            i_dim = non_bcast_shapes.pop()
+
+            potentially_unequal_dims = [
+                dim
+                for dim in non_bcast_shapes
+                # TODO FIXME: This is a largely deficient means of comparing graphs
+                # (and especially shapes)
+                if not theano.gof.graph.equal_computations([i_dim], [dim])
+            ]
+
+            if potentially_unequal_dims:
+                from theano.tensor.opt import Assert
+
+                # In this case, we can't tell whether or not the dimensions are
+                # equal, so we'll need to assert their equality and move the error
+                # handling to evaluation time.
+                assert_dim = Assert("Could not broadcast dimensions")
+                eq_condition = basic.all(
+                    [
+                        basic.or_(basic.eq(dim, one), basic.eq(i_dim, dim))
+                        for dim in potentially_unequal_dims
+                    ]
+                )
+                eq_condition = basic.or_(basic.eq(i_dim, one), eq_condition)
+                result_dims.append(assert_dim(i_dim, eq_condition))
+            else:
+                result_dims.append(i_dim)
+        else:
+            # Every array was broadcastable in this dimension
+            result_dims.append(one)
+
+    return tuple(result_dims)
