@@ -1,7 +1,7 @@
 import logging
 import warnings
 import numpy as np
-from six.moves import xrange
+
 from functools import partial
 
 import theano
@@ -152,7 +152,7 @@ matrix_inverse = MatrixInverse()
 
 
 def matrix_dot(*args):
-    r""" Shorthand for product between several dots.
+    r"""Shorthand for product between several dots.
 
     Given :math:`N` matrices :math:`A_0, A_1, .., A_N`, ``matrix_dot`` will
     generate the matrix product between all in the given order, namely
@@ -414,11 +414,11 @@ class EighGrad(Op):
         def G(n):
             return sum(
                 v[:, m] * V.T[n].dot(v[:, m]) / (w[n] - w[m])
-                for m in xrange(N)
+                for m in range(N)
                 if m != n
             )
 
-        g = sum(outer(v[:, n], v[:, n] * W[n] + G(n)) for n in xrange(N))
+        g = sum(outer(v[:, n], v[:, n] * W[n] + G(n)) for n in range(N))
 
         # Numpy's eigh(a, 'L') (eigh(a, 'U')) is a function of tril(a)
         # (triu(a)) only.  This means that partial derivative of
@@ -672,7 +672,7 @@ def matrix_power(M, n):
     n : Python int
     """
     result = 1
-    for i in xrange(n):
+    for i in range(n):
         result = theano.dot(result, M)
     return result
 
@@ -795,7 +795,10 @@ class TensorSolve(Op):
         return Apply(self, [a, b], [x])
 
     def perform(self, node, inputs, outputs):
-        (a, b,) = inputs
+        (
+            a,
+            b,
+        ) = inputs
         (x,) = outputs
         x[0] = self._numop(a, b, self.axes)
 
