@@ -2,14 +2,16 @@
 
 
 import sys
-from copy import copy
 
 import numpy as np
-from six import string_types
-from six.moves import reduce, xrange
 
-# local imports
 import theano
+
+from copy import copy
+from functools import reduce
+
+from six import string_types
+
 from theano import tensor
 from theano.tensor import opt
 from theano import gof
@@ -231,7 +233,7 @@ class RandomFunction(gof.Op):
             # Use the default infer_shape implementation.
             raise tensor.ShapeError()
 
-        return [None, [sample_shp[i] for i in xrange(node.outputs[1].ndim)]]
+        return [None, [sample_shp[i] for i in range(node.outputs[1].ndim)]]
 
     def perform(self, node, inputs, out_):
         rout, out = out_
@@ -445,7 +447,7 @@ def _generate_broadcasting_indices(out_shape, *shapes):
     # Will contain the return value: a list of indices for each argument
     ret_indices = [[()] for shape in all_shapes]
 
-    for dim in xrange(len(out_shape)):
+    for dim in range(len(out_shape)):
         # Temporary list to generate the indices
         _ret_indices = [[] for shape in all_shapes]
 
@@ -470,7 +472,7 @@ def _generate_broadcasting_indices(out_shape, *shapes):
 
         for prev_index in zip(*ret_indices):
             for dim_index in zip(*ranges):
-                for i in xrange(len(all_shapes)):
+                for i in range(len(all_shapes)):
                     _ret_indices[i].append(prev_index[i] + (dim_index[i],))
         ret_indices = _ret_indices
 
@@ -600,7 +602,7 @@ def random_integers_helper(random_state, low, high, size):
         out_size = tuple(size)
     else:
         out_size = ()
-        for dim in xrange(out_ndim):
+        for dim in range(out_ndim):
             dim_len = max(low.shape[dim], high.shape[dim])
             out_size = out_size + (dim_len,)
 
@@ -822,7 +824,7 @@ def multinomial_helper(random_state, n, pvals, size):
         size = tuple(size)
     else:
         size = ()
-        for dim in xrange(ndim):
+        for dim in range(ndim):
             dim_len = max(n.shape[dim], pvals.shape[dim])
             size = size + (dim_len,)
     out_size = size + (pvals.shape[-1],)
