@@ -1,6 +1,6 @@
 import logging
 import warnings
-from six.moves import xrange
+
 
 import numpy as np
 
@@ -140,8 +140,7 @@ cholesky = Cholesky()
 
 
 class CholeskyGrad(Op):
-    """
-    """
+    """"""
 
     __props__ = ("lower", "destructive")
 
@@ -181,23 +180,23 @@ class CholeskyGrad(Op):
         N = x.shape[0]
         if self.lower:
             F = np.tril(dz)
-            for k in xrange(N - 1, -1, -1):
-                for j in xrange(k + 1, N):
-                    for i in xrange(j, N):
+            for k in range(N - 1, -1, -1):
+                for j in range(k + 1, N):
+                    for i in range(j, N):
                         F[i, k] -= F[i, j] * L[j, k]
                         F[j, k] -= F[i, j] * L[i, k]
-                for j in xrange(k + 1, N):
+                for j in range(k + 1, N):
                     F[j, k] /= L[k, k]
                     F[k, k] -= L[j, k] * F[j, k]
                 F[k, k] /= 2 * L[k, k]
         else:
             F = np.triu(dz)
-            for k in xrange(N - 1, -1, -1):
-                for j in xrange(k + 1, N):
-                    for i in xrange(j, N):
+            for k in range(N - 1, -1, -1):
+                for j in range(k + 1, N):
+                    for i in range(j, N):
                         F[k, i] -= F[j, i] * L[k, j]
                         F[k, j] -= F[j, i] * L[k, i]
-                for j in xrange(k + 1, N):
+                for j in range(k + 1, N):
                     F[k, j] /= L[k, k]
                     F[k, k] -= L[k, j] * F[k, j]
                 F[k, k] /= 2 * L[k, k]
@@ -304,8 +303,6 @@ solve = Solve()
 Solves the equation ``a x = b`` for x, where ``a`` is a matrix and
 ``b`` can be either a vector or a matrix.
 
-Note
-
 Parameters
 ----------
 a : `(M, M) symbolix matrix`
@@ -447,7 +444,7 @@ def eigvalsh(a, b, lower=True):
 
 
 def kron(a, b):
-    """ Kronecker product.
+    """Kronecker product.
 
     Same as scipy.linalg.kron(a, b).
 
@@ -483,7 +480,7 @@ def kron(a, b):
     else:
         o = shf.reshape(
             (o.shape[0] * o.shape[2], o.shape[1] * o.shape[3])
-            + tuple(o.shape[i] for i in xrange(4, o.ndim))
+            + tuple(o.shape[i] for i in range(4, o.ndim))
         )
     return o
 
@@ -502,7 +499,15 @@ class Expm(Op):
         A = as_tensor_variable(A)
         assert A.ndim == 2
         expm = theano.tensor.matrix(dtype=A.dtype)
-        return Apply(self, [A,], [expm,])
+        return Apply(
+            self,
+            [
+                A,
+            ],
+            [
+                expm,
+            ],
+        )
 
     def perform(self, node, inputs, outputs):
         (A,) = inputs
@@ -531,7 +536,13 @@ class ExpmGrad(Op):
         A = as_tensor_variable(A)
         assert A.ndim == 2
         out = theano.tensor.matrix(dtype=A.dtype)
-        return Apply(self, [A, gw], [out,])
+        return Apply(
+            self,
+            [A, gw],
+            [
+                out,
+            ],
+        )
 
     def infer_shape(self, node, shapes):
         return [shapes[0]]
